@@ -15,6 +15,7 @@ if TYPE_CHECKING:
     from spark_auto_mapper.data_types.text_like_base import AutoMapperTextLikeBase
     from spark_auto_mapper.data_types.datetime import AutoMapperDateTimeDataType
     from spark_auto_mapper.data_types.date import AutoMapperDateDataType
+    from spark_auto_mapper.data_types.date_format import AutoMapperFormatDateTimeDataType
     from spark_auto_mapper.data_types.float import AutoMapperFloatDataType
 
 _TAutoMapperDataType = TypeVar(
@@ -59,7 +60,7 @@ class AutoMapperDataTypeBase:
         pass  # sub-classes can implement if they support this
 
     # noinspection PyMethodMayBeStatic
-    def transform(self,
+    def transform(self: 'AutoMapperDataTypeBase',
                   value: _TAutoMapperDataType) -> List[_TAutoMapperDataType]:
         """
         transforms a column into another type or struct
@@ -352,3 +353,93 @@ class AutoMapperDataTypeBase:
     # noinspection PyMethodMayBeStatic
     def get_schema(self, include_extension: bool) -> Optional[StructType]:
         return None
+
+    def to_date_format(
+        self: _TAutoMapperDataType, format_: str
+    ) -> 'AutoMapperFormatDateTimeDataType':
+        """
+        Converts a date or time into string
+
+
+        :param format_: format to use for trying to parse the value otherwise uses:
+                        y-M-d
+                        yyyyMMdd
+                        M/d/y
+        """
+        from spark_auto_mapper.data_types.date_format import AutoMapperFormatDateTimeDataType
+
+        return AutoMapperFormatDateTimeDataType(self, format_)
+
+    # noinspection PyMethodMayBeStatic
+    def to_null_if_empty(self: _TAutoMapperDataType) -> _TAutoMapperDataType:
+        """
+        returns null if the column is an empty string
+
+
+        :return: an automapper type
+        """
+        from spark_auto_mapper.data_types.null_if_empty import AutoMapperNullIfEmptyDataType
+
+        # cast it to the inner type so type checking is happy
+        return cast(
+            _TAutoMapperDataType, AutoMapperNullIfEmptyDataType(value=self)
+        )
+
+    def regex_replace(
+        self: _TAutoMapperDataType, pattern: str, replacement: str
+    ) -> _TAutoMapperDataType:
+        """
+        Replace all substrings of the specified string value that match regexp with replacement.
+
+        :param pattern: pattern to search for
+        :param replacement: string to replace with
+        :return: a regex_replace automapper type
+        """
+
+        from spark_auto_mapper.data_types.regex_replace import AutoMapperRegExReplaceDataType
+
+        # cast it to the inner type so type checking is happy
+        # noinspection Mypy
+        return cast(
+            _TAutoMapperDataType,
+            AutoMapperRegExReplaceDataType(
+                column=self, pattern=pattern, replacement=replacement
+            )
+        )
+
+    def sanitize(
+        self: _TAutoMapperDataType,
+        replacement: str = " "
+    ) -> _TAutoMapperDataType:
+        """
+        Replaces all "non-normal" characters with specified replacement
+
+        We're using the FHIR definition of valid string
+        https://www.hl7.org/fhir/datatypes.html#string
+        Valid characters are (regex='[ \r\n\t\\S]'):
+        \\S - Any character that is not a whitespace character
+           - space
+        \r - carriage return
+        \n - line feed
+        \t - tab
+
+        :param replacement: (Optional) string to replace with.  Defaults to space.
+        :return: a regex_replace automapper type
+        """
+
+        from spark_auto_mapper.data_types.regex_replace import AutoMapperRegExReplaceDataType
+
+        # https://www.hl7.org/fhir/datatypes.html#string
+        # So we replace any character that is not normal per our definition above
+        not_normal_characters: str = r"[^ \r\n\t\S]"
+
+        # cast it to the inner type so type checking is happy
+        # noinspection Mypy
+        return cast(
+            _TAutoMapperDataType,
+            AutoMapperRegExReplaceDataType(
+                column=self,
+                pattern=not_normal_characters,
+                replacement=replacement
+            )
+        )
