@@ -49,7 +49,7 @@ class AutoMapperIfNotNullDataType(
         )
 
     def get_column_spec(
-        self, source_df: DataFrame, current_column: Optional[Column]
+        self, source_df: Optional[DataFrame], current_column: Optional[Column]
     ) -> Column:
         column_spec = when(
             self.check.get_column_spec(
